@@ -55,6 +55,7 @@ pub fn ansi_to_text<'t, B: IntoIterator<Item = u8>>(bytes: B) -> Result<Text<'t>
             // if byte after \x1b was not [ lock the stack
             ansi_stack.lock();
         }
+
         if ansi_stack.is_locked() && byte != b'\n' && byte != b'\x1b' {
             if line_styled_buffer.is_empty()
                 && !line_buffer.is_empty()
@@ -118,7 +119,16 @@ pub fn ansi_to_text<'t, B: IntoIterator<Item = u8>>(bytes: B) -> Result<Text<'t>
                     ansi_stack.push(stack.parse_usize()?);
                     // patch since the last style is not overwritten, only modified with a new
                     // sequence.
-                    style = style.patch(ansi_stack.parse_ansi()?);
+
+                    let _style_new = ansi_stack.parse_ansi()?;
+
+                    if _style_new == Style::default() {
+                        style = _style_new;
+                    } else {
+                        // style.patch doesn't work for Style::default() for some reason.
+                        style = style.patch(_style_new);
+                    }
+
                     if style_stack.is_empty() {
                         style_stack.push(style);
                     }
